@@ -230,10 +230,10 @@ mvar <- function(data,         # n x p data matrix
       # overwrite above
       data_lagged <- lagData(data = data, 
                              lags = lags, 
-                             consec = NULL) # consec comes out of the bootstrap args$boot_ind
+                             consec = consec)
       
-      data_response <- data_lagged$data_response
-      l_data_lags <- data_lagged$l_data_lags
+      data_response <- data_lagged$data_response[data_lagged$included, ]
+      l_data_lags <- lapply(data_lagged$l_data_lags, function(x) x[data_lagged$included, ] )
       
       # overwrite data with bootstrap sample, passed on from resample()
       data_response <- data_response[args$boot_ind, ] # args$boot_ind is defined such that it only selects valid rows
@@ -245,8 +245,6 @@ mvar <- function(data,         # n x p data matrix
     }
   }
   
-  # browser()
-  
   # -------------------- Input Checks Local (for each set of predictors) -------------------
   
   # This checks glmnet requirements wrt categorical predictors, for each lag set
@@ -262,8 +260,6 @@ mvar <- function(data,         # n x p data matrix
     
   }
   
-  # browser()
-  
   # ----- Storage: Create empty mgm object -----
   
   mvarobj <- list('call' = NULL, # fill in later
@@ -328,7 +324,6 @@ mvar <- function(data,         # n x p data matrix
   # Progress bar
   if(pbar==TRUE) pb <- txtProgressBar(min = 0, max=p, initial=0, char="-", style = 3)
   
-  
   # Save number of parameters of standard (non-overparameterized) design matrices for tau threshold
   npar_standard <- rep(NA, p)
   
@@ -376,10 +371,6 @@ mvar <- function(data,         # n x p data matrix
       
     }
     
-    
-    # browser()
-    
-    
     # ----- Fit each neighborhood using the same procedure as in mgm -----
     
     # ----- Tuning Parameter Selection (lambda and alpha) -----
@@ -397,7 +388,6 @@ mvar <- function(data,         # n x p data matrix
       
       if(n_alpha>1) {
         
-        
         # For: alpha
         for(a in 1:n_alpha) {
           
@@ -415,6 +405,7 @@ mvar <- function(data,         # n x p data matrix
             # Recompute variables for training set
             n_train <- nrow(train_X)
             nadj_train <- sum(weights_design[ind != fold])
+          
             
             l_foldmodels[[fold]] <- nodeEst(y = train_y,
                                             X = train_X,
@@ -472,8 +463,6 @@ mvar <- function(data,         # n x p data matrix
       
       # Refit Model on whole data, with selected alpha
       
-      # browser()
-      
       model <- nodeEst(y = y,
                        X = X,
                        lambdaSeq = lambdaSeq,
