@@ -15,11 +15,14 @@ nodeEst <- function(y,
                     type,
                     level,
                     emp_lev,
-                    overparameterize)
+                    overparameterize, 
+                    thresholdCat)
 
 
 {
 
+  # browser()
+  
 # if(v == 1) browser()
   
   # ---------- Calc Aux Variables ----------
@@ -30,10 +33,11 @@ nodeEst <- function(y,
   if(type[v] == 'p') fam = 'poisson'
   
   
-  if(type[v] == 'c' & overparameterize) {
-    intercept <- FALSE 
+  # Set threshold (intercept) parameter to zero?
+  if(type[v] == 'c') {
+    intercept <- thresholdCat
   } else {
-    intercept <- TRUE 
+    intercept <- TRUE # for continuous variables always estimated
   }
 
 
@@ -44,6 +48,8 @@ nodeEst <- function(y,
 
     # ----- Fit Model -----
   
+    # if(v == 3) browser()
+    
     fit <- glmnet(x = X,
                   y = y,
                   family = fam,
@@ -52,6 +58,8 @@ nodeEst <- function(y,
                   lambda = lambdaSeq,
                   intercept = intercept)
 
+
+    
     n_lambdas <- length(fit$lambda) # length of fitted lambda sequence
 
     # coef(fit, s = fit$lambda[61])
@@ -134,7 +142,6 @@ nodeEst <- function(y,
     lambda_min <- fit$lambda[ind_lambda_min]
     lambad_min_model <- coef(fit, s = lambda_min)
 
-
     # ----- Output -----
 
     outlist <- list('EBIC' = EBIC_min,
@@ -155,6 +162,8 @@ nodeEst <- function(y,
 
     # ----- Fit Model -----
     
+    # browser()
+    
     # browser()
 
     fit <- cv.glmnet(x = X,
